@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute Halstead complexity metrics
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0500';
 
 use Moo;
 use strictures 2;
@@ -120,8 +120,11 @@ sub BUILD {
         $item =~ s/\s*$//;
         my @item = split /\s+/, $item, 2;
         next unless defined $item[1];
+        next if $item[0] eq 'PPI::Token::Comment'
+            or $item[0] eq 'PPI::Token::Pod';
         push @{ $halstead{ $item[0] } }, $item[1];
     }
+#use Data::Dumper;warn(__PACKAGE__,' ',__LINE__,' ',Dumper\%halstead);
 
     $self->{n_operators} = 0;
     $self->{n_operands}  = 0;
@@ -147,6 +150,7 @@ sub BUILD {
             }
         }
     }
+#use Data::Dumper;warn(__PACKAGE__,' ',__LINE__,' ',Dumper\%distinct);
 
     $self->{n_distinct_operators} = keys %{ $distinct{operators} };
     $self->{n_distinct_operands}  = keys %{ $distinct{operands} };
@@ -193,8 +197,7 @@ sub dump {
 
 sub _is_operand {
     my $key = shift;
-    return $key eq 'PPI::Token::Comment'
-        || $key eq 'PPI::Token::Number'
+    return $key eq 'PPI::Token::Number'
         || $key eq 'PPI::Token::Symbol'
         || $key eq 'PPI::Token::Pod'
         || $key eq 'PPI::Token::HereDoc'
@@ -220,7 +223,7 @@ Perl::Metrics::Halstead - Compute Halstead complexity metrics
 
 =head1 VERSION
 
-version 0.0401
+version 0.0500
 
 =head1 SYNOPSIS
 
